﻿using System.ComponentModel.DataAnnotations;

namespace Connected.Security.Authentication
{
	/// <summary>
	/// Represents the Single Sign On arguments.
	/// </summary>
	/// <remarks>
	/// Once users are successfully authenticated against the identity the 
	/// authentication token is returned by the <see cref="IAuthenticationResult"/>. 
	/// This token can be later used by any client to perform authentication and get the user's identity.
	/// </remarks>
	public sealed class SsoAuthenticationArgs : AuthenticationArgs
	{
		/// <summary>
		/// The security token issued by the <see cref="IAuthenticationMiddleware"/>. The system
		/// can match the user's identity based on this value. Tat means the token is unique
		/// across the entire environment.
		/// </summary>
		[Required]
		[MaxLength(128)]
		public string Token { get; init; }
	}
}
